==> haskell-crypto-pubkey-0.2.8-157-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-pubkey.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-pubkey
version:              0.2.8
visibility:           public
id:                   crypto-pubkey-0.2.8-JaRnzVor8AKFBoA1kojjmT
key:                  crypto-pubkey-0.2.8-JaRnzVor8AKFBoA1kojjmT
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             https://github.com/vincenthz/hs-crypto-pubkey
synopsis:             Public Key cryptography
description:
    Public Key cryptography

    Supports RSA PKCS15, RSA OAEP, RSA PSS, DSA, ElGamal signature.

    Also have primitive support for Diffie Hellman, and ElGamal encryption

category:             Cryptography
abi:                  21885bc43a3162ae1edb9a377f999294
exposed:              True
exposed-modules:
    Crypto.PubKey.DH Crypto.PubKey.DSA Crypto.PubKey.ECC.DH
    Crypto.PubKey.ECC.ECDSA Crypto.PubKey.ECC.Generate
    Crypto.PubKey.ECC.Prim Crypto.PubKey.HashDescr
    Crypto.PubKey.MaskGenFunction Crypto.PubKey.RSA
    Crypto.PubKey.RSA.OAEP Crypto.PubKey.RSA.PKCS15
    Crypto.PubKey.RSA.PSS Crypto.PubKey.RSA.Prim

hidden-modules:
    Crypto.PubKey.ElGamal Crypto.PubKey.RSA.Types
    Crypto.PubKey.Internal

import-dirs:          /usr/lib/ghc-8.10.1/site-local/crypto-pubkey-0.2.8
library-dirs:         /usr/lib/ghc-8.10.1/site-local/crypto-pubkey-0.2.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/crypto-pubkey-0.2.8
hs-libraries:         HScrypto-pubkey-0.2.8-JaRnzVor8AKFBoA1kojjmT
depends:
    base-4.14.0.0 byteable-0.1.1-EIsD8YjxajzGjEMLynBvyB
    bytestring-0.10.10.0 crypto-numbers-0.2.7-3shXKtr17ct6bcUBM5i65G
    crypto-pubkey-types-0.4.3-IPNvXCw0QEm3I2vxUYC2xs
    crypto-random-0.0.9-2WFZ3jgfgEw2IAMGLNAHdy
    cryptohash-0.11.9-B1eI9kNNZRJLLblw9lQi5x

haddock-interfaces:
    /usr/share/doc/haskell-crypto-pubkey/html/crypto-pubkey.haddock

haddock-html:         /usr/share/doc/haskell-crypto-pubkey/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-pubkey-0.2.8-158-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-pubkey.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-pubkey
version:              0.2.8
visibility:           public
id:                   crypto-pubkey-0.2.8-FZKLx53SKX7J5w899AjVAB
key:                  crypto-pubkey-0.2.8-FZKLx53SKX7J5w899AjVAB
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             https://github.com/vincenthz/hs-crypto-pubkey
synopsis:             Public Key cryptography
description:
    Public Key cryptography

    Supports RSA PKCS15, RSA OAEP, RSA PSS, DSA, ElGamal signature.

    Also have primitive support for Diffie Hellman, and ElGamal encryption

category:             Cryptography
abi:                  b2d19ba4dbe4d8eca14e6515740b5f14
exposed:              True
exposed-modules:
    Crypto.PubKey.DH Crypto.PubKey.DSA Crypto.PubKey.ECC.DH
    Crypto.PubKey.ECC.ECDSA Crypto.PubKey.ECC.Generate
    Crypto.PubKey.ECC.Prim Crypto.PubKey.HashDescr
    Crypto.PubKey.MaskGenFunction Crypto.PubKey.RSA
    Crypto.PubKey.RSA.OAEP Crypto.PubKey.RSA.PKCS15
    Crypto.PubKey.RSA.PSS Crypto.PubKey.RSA.Prim

hidden-modules:
    Crypto.PubKey.ElGamal Crypto.PubKey.RSA.Types
    Crypto.PubKey.Internal

import-dirs:          /usr/lib/ghc-8.10.2/site-local/crypto-pubkey-0.2.8
library-dirs:         /usr/lib/ghc-8.10.2/site-local/crypto-pubkey-0.2.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/crypto-pubkey-0.2.8
hs-libraries:         HScrypto-pubkey-0.2.8-FZKLx53SKX7J5w899AjVAB
depends:
    base-4.14.1.0 byteable-0.1.1-FeSdIMqUIcwI3U3IhpOBJ3
    bytestring-0.10.10.0 crypto-numbers-0.2.7-4ZZLZ4HoISJEpoVwYywzpJ
    crypto-pubkey-types-0.4.3-CNS87hURbwDCMsbmglGmKc
    crypto-random-0.0.9-GPxOeTz2E11EnnLzznRPcV
    cryptohash-0.11.9-Ah2lmvC5w5L7DPL0FWRNIZ

haddock-interfaces:
    /usr/share/doc/haskell-crypto-pubkey/html/crypto-pubkey.haddock

haddock-html:         /usr/share/doc/haskell-crypto-pubkey/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
